#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : www.playonlinux.com
# source location	: http://www.playonlinux.com/script_files/PlayOnLinux/3.5/PlayOnLinux_3.6.tar.gz
# last revised       : 21.10.2009
# dep                : 

softname='playonlinux'
softnamesrc='PlayOnLinux'
softversion='3.7'
packageversion='1fb'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname"
srcpkg="$buildir/"$softnamesrc"_"$softversion".tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.playonlinux.com/script_files/PlayOnLinux/3.7/"$softnamesrc"_"$softversion".tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
           |-----handy-ruler------------------------------------------------------|
playonlinux: playonlinux (Easily play Windows games under linux)
playonlinux:
playonlinux: PlayOnLinux is a piece of software which allows you to easily install
playonlinux: and use numerous games and softwares designed to run with 
playonlinux: Microsoft's Windows
playonlinux:
playonlinux:
playonlinux:
playonlinux:
playonlinux:
playonlinux:
EOF

# check if source is present
if [ -f "$softnamesrc"_"$softversion".tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg

# build
cp -av playonlinux $dest/usr/share
rm $dest/usr/share/playonlinux/CHANGELOG

# make icon
cp $softname.png $dest/usr/share/icons/hicolor/48x48/apps/$softname.png

# make the .desktop file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=PlayOnLinux
Comment=PlayOnLinux
Exec=playonlinux
Icon=playonlinux
Terminal=false
Type=Application
Categories=Game;
Encoding=UTF-8
EOF

cat <<EOF > $dest/usr/bin/playonlinux
#!/bin/sh
/usr/share/playonlinux/playonlinux "\$@"
EOF

chmod 755 $dest/usr/bin/playonlinux

cat <<EOF > $dest/usr/bin/playonlinux-deamon
#!/bin/sh
/usr/share/playonlinux/playonlinux-deamon "\$@"
EOF

chmod 755 $dest/usr/bin/playonlinux-deamon

cat <<EOF > $dest/usr/bin/playonlinux-pkg
#!/bin/sh
/usr/share/playonlinux/playonlinux-pkg "\$@"
EOF

chmod 755 $dest/usr/bin/playonlinux-pkg

# add 'default' files
    cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      CHANGELOG LICENCE \
      $dest/usr/doc/$softname-$softversion

# strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# SalixBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp $softname.png $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "cabextract,imagemagick,lynx,lzma,python,wine,wxGTK,wxPython" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/xap/playonlinux/source/build-playonlinux.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/xap/playonlinux/source/playonlinux.png > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
